@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | APC                                                                  |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2015-2018 The PHP Group                                |
+  | Copyright (c) 2015-2019 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -63,8 +63,6 @@ static PHP_MINFO_FUNCTION(apc)
 {
     php_info_print_table_start();
     php_info_print_table_row(2, "APC Compatibility", PHP_APCU_BC_VERSION);
-    php_info_print_table_row(2, "APCu Version", PHP_APCU_VERSION);
-    php_info_print_table_row(2, "Build Date", __DATE__ " " __TIME__);
     php_info_print_table_end();
 }
 /* }}} */
@@ -194,9 +192,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_apc_iterator___construct, 0, 0, 1)
 	ZEND_ARG_INFO(0, chunk_size)
 	ZEND_ARG_INFO(0, list)
 ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_apc_iterator_void, 0, 0, 0)
-ZEND_END_ARG_INFO()
 /* }}} */
 
 /* {{{ proto object APCIterator::__construct(cache, [ mixed search [, long format [, long chunk_size [, long list ]]]]) */
